@@ -206,7 +206,7 @@ void PocoDatabaseImpl::DeleteAllCollections () throw (Xception)
 
 	try
 	{
-		DBTransactor transactor(m_pSession);
+		DBTransactor transactor(m_pSession, m_transactionCounter);
 
 		CollectionMetaInfos to_delete;
 		foreach (const CollectionMetaInfo& cmi, m_collectionMetaInfos)
@@ -359,7 +359,7 @@ void PocoDatabaseImpl::AddCollectionsItems (const CollectionsItems& items) throw
 {
 	try
 	{
-		DBTransactor transactor(m_pSession);
+		DBTransactor transactor(m_pSession, m_transactionCounter);
 
 		foreach (const CollectionsItems::value_type& vt, items)
 		{
@@ -389,7 +389,7 @@ void PocoDatabaseImpl::AddCollectionsItems (const CollectionsItems& items) throw
 	}
 	catch (...)
 	{
-		throw Xception("could not add collections items");
+		throw Xception("could not add collection items");
 	}
 }
 
@@ -397,7 +397,7 @@ void PocoDatabaseImpl::DeleteCollectionsItems (const ptime& timestamp, const Col
 {
 	try
 	{
-		DBTransactor transactor(m_pSession);
+		DBTransactor transactor(m_pSession, m_transactionCounter);
 
 		const string& t = lexical_cast<string>(timestamp);
 		foreach (const CollectionMetaInfo& cmi, m_collectionMetaInfos)
