@@ -54,7 +54,7 @@ void MySQLDatabase::NoSchemaCallback () throw (Xception)
 
 	try
 	{
-		DBTransactor transactor(m_pSession);
+		DBTransactor transactor(m_pSession, m_transactionCounter);
 
 		(*m_pSession) << "create table TCollections "
 				 "("
@@ -97,7 +97,7 @@ void MySQLDatabase::CreateCollectionInSchema (const string& name, char type, con
 {
 	try
 	{
-		DBTransactor transactor(m_pSession);
+		DBTransactor transactor(m_pSession, m_transactionCounter);
 
 		string sql("create table ");
 		sql += tblname;
@@ -126,7 +126,7 @@ void MySQLDatabase::DropCollectionFromSchema (const string& tblname) throw (Xcep
 {
 	try
 	{
-		DBTransactor transactor(m_pSession);
+		DBTransactor transactor(m_pSession, m_transactionCounter);
 
 		(*m_pSession) << "delete from TCollections where tbl_name=?;", use(tblname), now;
 		(*m_pSession) << "drop table " << tblname << ";", now;
