@@ -39,6 +39,7 @@ void InputImpl::Parse (const string& expr, const ptime& timestamp, bool verbose,
 	string line(expr);
 
 	static const regex rx_comment("[;#]\\s*(.+)\\s*$");					// #... ;...
+	static const regex rx_datetime("([0-9]{1,4})-([0-9]{1,2})-([0-9]{1,2})-([0-9]{1,2})[:]([0-9]{1,2})(?:[:]([0-9]{1,2}))?"); // 2009-02-27-15:27[:59]
 	static const regex rx_time("([0-9]{1,2})[:]([0-9]{1,2})(?:[:]([0-9]{1,2}))?");		// 15:27[:59]
 	static const regex rx_date("([0-9]{1,4})-([0-9]{1,2})-([0-9]{1,2})");			// 2009-02-27
 	static const regex rx_ratio("([0-9]+(?:\\.[0-9]+)?)([/%])([0-9]+(?:\\.[0-9]+)?)");	// double[/%]double
@@ -57,30 +58,51 @@ void InputImpl::Parse (const string& expr, const ptime& timestamp, bool verbose,
 	// if the expression contains date and/or time components, adapt the
 	// timestamp variable
 	ptime t(timestamp);
-	if (regex_search(line, mr, rx_time, boost::match_not_dot_newline))
+	if (regex_search(line, mr, rx_datetime, boost::match_not_dot_newline))
 	{
-		// time found
+		int year, month, day, hour, min, sec;
+		year = lexical_cast<int>(mr[1]);
+		month = lexical_cast<int>(mr[2]);
+		day = lexical_cast<int>(mr[3]);
+		hour = lexical_cast<int>(mr[4]);
+		min = lexical_cast<int>(mr[5]);
+		sec = (mr[6].length() > 0) ? lexical_cast<int>(mr[6]) : 0;
+		t = ptime(date(year, month, day), time_duration(hour, min, sec, 0));
+		line.erase(mr.position(), mr.length());
+	}
+	else
+	{
+		if (regex_search(line, mr, rx_time, boost::match_not_dot_newline))
 		{
-			int hour, min, sec;
-			hour = lexical_cast<int>(mr[1]);
-			min = lexical_cast<int>(mr[2]);
-			sec = (mr[3].length() > 0) ? lexical_cast<int>(mr[3]) : 0;
-			t -= t.time_of_day();
-			t += time_duration(hour, min, sec, 0);
-			line.erase(mr.position(), mr.length());
-		}
+			// time found
+			{
+				int hour, min, sec;
+				hour = lexical_cast<int>(mr[1]);
+				min = lexical_cast<int>(mr[2]);
+				sec = (mr[3].length() > 0) ? lexical_cast<int>(mr[3]) : 0;
+				t -= t.time_of_day();
+				t += time_duration(hour, min, sec, 0);
+				line.erase(mr.position(), mr.length());
+			}
 
-		if (regex_search(line, mr, rx_date, boost::match_not_dot_newline))
-		{
-			// date found
-			int year, month, day;
-			year = lexical_cast<int>(mr[1]);
-			month = lexical_cast<int>(mr[2]);
-			day = lexical_cast<int>(mr[3]);
-			t = ptime(date(year, month, day), t.time_of_day());
-			line.erase(mr.position(), mr.length());
+			if (regex_search(line, mr, rx_date, boost::match_not_dot_newline))
+			{
+				// date found
+				int year, month, day;
+				year = lexical_cast<int>(mr[1]);
+				month = lexical_cast<int>(mr[2]);
+				day = lexical_cast<int>(mr[3]);
+				t = ptime(date(year, month, day), t.time_of_day());
+				line.erase(mr.position(), mr.length());
+			}
 		}
 	}
+	if (t == not_a_date_time)
+	{
+		// date is syntactical correct but contains an invalid
+		// point in history, 2010-25-39-84:97 or so
+		throw Xception(format("illegal timestamp in expression: %s") % expr);
+	}
 
 	if (verbose)
 	{
