@@ -131,9 +131,9 @@ void Pop3MailClient::Do (const Config& config, Database& database) const throw (
 			{
 				try
 				{
-					Database::CollectionElements elements;
-					Parse(line, timestamp, verbose, elements);
-					database.AddCollectionElements(elements);
+					Database::CollectionsItems items;
+					Parse(line, timestamp, verbose, items);
+					database.AddCollectionsItems(items);
 				}
 				catch (const Xception& )
 				{
