@@ -38,7 +38,7 @@ Database* DBFactory::Create (const Config& config) throw (Xception)
 	if (database_type.empty())
 		throw Xception("missing specification in configuration file: database.type");
 
-	DatabaseImpl* pDatabase = NULL;
+	Database* pDatabase = NULL;
 #ifdef USE_SQLITE
 	if (database_type == "sqlite")
 	{
